Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( DarkGray = color.NRGBA{R: 0x2B, G: 0x2B, B: 0x2B, A: 0xFF} Gray = color.NRGBA{R: 0x75, G: 0x75, B: 0x75, A: 0xFF} LightGray = color.NRGBA{R: 0xCF, G: 0xCF, B: 0xCF, A: 0xFF} )
Colors
Functions ¶
Types ¶
type D ¶
type D = layout.Dimensions
type HSplit ¶
type HSplit struct{}
HSplit is a custom layout with two widgets of equal size separated by a vertical bar.
type VSplit ¶
type VSplit struct {
// Ratio keeps the current layout.
// 0 is center, -1 completely to the left, 1 completely to the right.
Ratio float32
// Bar is the width for resizing the layout
Bar unit.Value
// contains filtered or unexported fields
}
VSplit is a custom layout with two widgets of adjustable size separated by a draggable horizontal bar.
Click to show internal directories.
Click to hide internal directories.